@@ -45,7 +45,7 @@ public:
      * It is assumed that a minimum of one identity is always present.
      */
     explicit IdentityManager(bool readonly = false, QObject *parent = nullptr, const char *name = nullptr);
-    virtual ~IdentityManager();
+    ~IdentityManager() override;
 
     /**
      * Creates or reuses the identity manager instance for this process.
@@ -124,7 +124,7 @@ public:
      **/
     const Identity &identityForUoid(uint uoid) const;
 
-    /** Convenience menthod.
+    /** Convenience method.
 
         @return the identity with Unique Object Identifier (UOID) @p
                 uoid or the default identity if not found.
@@ -216,9 +216,7 @@ protected:
      * values from KUser, but reimplementations of this method can give
      * them another value.
      */
-    virtual void createDefaultIdentity(QString & /*fullName*/, QString & /*emailAddress*/)
-    {
-    }
+    virtual void createDefaultIdentity(QString & /*fullName*/, QString & /*emailAddress*/);
 
 protected Q_SLOTS:
     void slotRollback();
